@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailVariableCreator.h 2185 2006-12-08 17:25:48Z svn $
+ * $Id: ThumbnailVariableCreator.h 2296 2006-12-24 02:58:57Z svn $
  *****************************************************************************/
 
 #ifndef THUMBNAIL_VARIABLE_CREATOR_H
@@ -36,7 +36,6 @@
 #include "TemplateVariable.h"
 #include "Uncopyable.h"
 
-using namespace std;
 
 class ThumbnailIterator;
 
@@ -74,7 +73,7 @@ private:
     TemplateVariable::variable_t *create_thumbnail(apr_pool_t *pool,
                                                    apr_size_t item_id,
                                                    void *var_memory,
-                                                   void *sca_memory) const throw();
+                                                   void *sca_memory) const;
 
     apr_size_t get_thumbnail_array_memory_size(apr_size_t list_size) const;
     apr_size_t get_thumbnail_memory_size() const;
