@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.h 2283 2006-12-20 15:19:04Z svn $
+ * $Id: UploadItemVariableCreator.h 2296 2006-12-24 02:58:57Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_VARIABLE_CREATOR_H
@@ -35,7 +35,6 @@
 #include "TemplateVariable.h"
 #include "Uncopyable.h"
 
-using namespace std;
 
 class UploadItemIterator;
 
@@ -95,7 +94,7 @@ private:
     TemplateVariable::variable_t *create_item(apr_pool_t *pool,
                                               UploadItem *uitem,
                                               void *var_memory,
-                                              void *sca_memory) const throw();
+                                              void *sca_memory) const;
 
     apr_size_t get_item_array_memory_size(apr_size_t list_size) const;
     apr_size_t get_item_memory_size() const;
