@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponseWriter.cpp 2274 2006-12-17 13:55:21Z svn $
+ * $Id: ApacheResponseWriter.cpp 2297 2006-12-24 03:13:15Z svn $
  *****************************************************************************/
 
 // Apache の config.h を先に処理させるため，util_filter.h のインクルードはこの位置
@@ -39,7 +39,7 @@
 #include "ApacheResponseWriter.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2274 2006-12-17 13:55:21Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2297 2006-12-24 03:13:15Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -134,7 +134,7 @@ int ApacheResponseWriter::sendfile(request_rec *r, apr_file_t *file,
 /******************************************************************************
  * public メソッド
  ****************************************************************************/
-void ApacheResponseWriter::flush() throw()
+void ApacheResponseWriter::flush()
 {
     if (UNLIKELY((iovec_count_ == 0) || connection_->aborted)) {
         iovec_count_ = 0;
@@ -147,7 +147,7 @@ void ApacheResponseWriter::flush() throw()
     iovec_count_ = 0;
 }
 
-bool ApacheResponseWriter::is_mmap_enabled(request_rec *r) throw()
+bool ApacheResponseWriter::is_mmap_enabled(request_rec *r)
 {
 #if APR_HAS_MMAP
     core_dir_config *core_config;
@@ -161,7 +161,7 @@ bool ApacheResponseWriter::is_mmap_enabled(request_rec *r) throw()
 #endif
 }
 
-bool ApacheResponseWriter::is_sendfile_enabled(request_rec *r) throw()
+bool ApacheResponseWriter::is_sendfile_enabled(request_rec *r)
 {
 #if APR_HAS_SENDFILE
     core_dir_config *core_config;
