@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemIterator.cpp 2170 2006-12-04 17:23:49Z svn $
+ * $Id: UploadItemIterator.cpp 2297 2006-12-24 03:13:15Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "UploadItemList.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2170 2006-12-04 17:23:49Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2297 2006-12-24 03:13:15Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -58,17 +58,17 @@ UploadItemIterator::UploadItemIterator(apr_pool_t *pool,
     }
 }
 
-UploadItem *UploadItemIterator::get() const throw()
+UploadItem *UploadItemIterator::get() const
 {
     return AS_UITEM(header_list_ + curr_index_);
 }
 
-bool UploadItemIterator::next() throw()
+bool UploadItemIterator::next()
 {
     return (++curr_index_ < size_);
 }
 
-void UploadItemIterator::reset() throw()
+void UploadItemIterator::reset()
 {
     curr_index_ = 0;
 }
