@@ -88,7 +88,6 @@
             this.tabPage3 = new System.Windows.Forms.TabPage();
             this.errorTmplPathLabel = new System.Windows.Forms.Label();
             this.errorTmplPathTextBox = new System.Windows.Forms.TextBox();
-
             this.errorTmplPathButton = new System.Windows.Forms.Button();
             this.adminTmplPathButton = new System.Windows.Forms.Button();
             this.adminTmplPathTextBox = new System.Windows.Forms.TextBox();
@@ -108,6 +107,7 @@
             this.toolStripSeparator1 = new System.Windows.Forms.ToolStripSeparator();
             this.helpStripButton = new System.Windows.Forms.ToolStripButton();
             this.copyButton = new System.Windows.Forms.Button();
+            this.bindingSource1 = new System.Windows.Forms.BindingSource(this.components);
             ((System.ComponentModel.ISupportInitialize)(this.uploaderConfigBindingSource)).BeginInit();
             this.configTabControl.SuspendLayout();
             this.tabPage1.SuspendLayout();
@@ -121,10 +121,10 @@
             ((System.ComponentModel.ISupportInitialize)(this.perPageItemNumberNumericUpDown)).BeginInit();
             ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).BeginInit();
             this.tabPage3.SuspendLayout();
-
             ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).BeginInit();
             this.groupBox1.SuspendLayout();
             this.menuToolStrip.SuspendLayout();
+            ((System.ComponentModel.ISupportInitialize)(this.bindingSource1)).BeginInit();
             this.SuspendLayout();
             // 
             // thumbDirPathLabel
@@ -355,6 +355,7 @@
             this.modulePathTextBox.TabIndex = 7;
             this.modulePathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             this.modulePathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.modulePathTextBox_Validating);
+
             // 
             // imagemagickPathButton
             // 
@@ -384,6 +385,7 @@
             this.apachePathTextBox.TabIndex = 1;
             this.apachePathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             this.apachePathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.apachePathTextBox_Validating);
+
             // 
             // apachePathLabel
             // 
@@ -760,10 +762,6 @@
             this.errorTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.errorTmplPathTextBox.TabIndex = 17;
             this.errorTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
-            // 
-            // uploaderConfigBindingSource1
-            // 
-
             // 
             // errorTmplPathButton
             // 
@@ -899,7 +897,7 @@
             this.menuToolStrip.Size = new System.Drawing.Size(457, 25);
             this.menuToolStrip.TabIndex = 0;
             this.menuToolStrip.Text = "toolStrip1";
-            this.menuToolStrip.ItemClicked += new System.Windows.Forms.ToolStripItemClickedEventHandler(this.menuToolStrip_ItemClicked);
+
             // 
             // copyToolStripButton
             // 
@@ -983,12 +981,12 @@
             ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).EndInit();
             this.tabPage3.ResumeLayout(false);
             this.tabPage3.PerformLayout();
-
             ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).EndInit();
             this.groupBox1.ResumeLayout(false);
             this.groupBox1.PerformLayout();
             this.menuToolStrip.ResumeLayout(false);
             this.menuToolStrip.PerformLayout();
+            ((System.ComponentModel.ISupportInitialize)(this.bindingSource1)).EndInit();
             this.ResumeLayout(false);
             this.PerformLayout();
 
@@ -1076,5 +1074,6 @@
         private System.Windows.Forms.TextBox errorTmplPathTextBox;
 
         private System.Windows.Forms.Button errorTmplPathButton;
+        private System.Windows.Forms.BindingSource bindingSource1;
     }
 }
\ No newline at end of file
