@@ -32,7 +32,7 @@ namespace UploaderConfig
 
         private static string getApacheDir()
         {
-            string keyName = "Software\\Apache Group\\Apache";
+            string keyName = "Software\\Apache Software Foundation\\Apache";
             string valueName = "ServerRoot";
 
             string dir = "";
@@ -412,7 +412,7 @@ namespace UploaderConfig
         {
             string path = (sender as TextBox).Text;
 
-            if (!File.Exists(Path.Combine(Path.Combine(path, "bin"), "Apache.exe"))) {
+            if (!File.Exists(Path.Combine(Path.Combine(path, "bin"), "httpd.exe"))) {
                 errorProvider.SetError(sender as TextBox,
                     "u" + apachePathLabel.Text + "v܂");
                 return;
